@@ -48,25 +48,17 @@ HBASE_BACKUP_VERSION = (
 # create-cluster options help text
 
 CREATE_CLUSTER_DESCRIPTION = (
-    '<p>Creates an Amazon EMR cluster with the specified configurations.</p>'
-    '<p>Quick start:</p>'
-    '<p><code>aws emr create-cluster --release-label <release-label>'
-    ' --instance-type <instance-type> --instance-count <instance-count></code></p>'
-    '<p>Values for the following can be set in the AWS CLI'
-    ' config file using the <code>aws configure set</code> command: <code>--service-role, --log-uri,'
-    ' and InstanceProfile and KeyName arguments under --ec2-attributes</code>.</p>')
+    'Creates an Amazon EMR cluster with the specified configurations.')
 
 DESCRIBE_CLUSTER_DESCRIPTION = (
-    '<p>Provides  cluster-level details including status, hardware'
-    ' and software configuration, VPC settings, bootstrap'
-    ' actions, instance groups and so on.</p>'
-    '<p>Permissions needed for describe-cluster include:'
-    '<ul><li><code>elasticmapreduce:ListBootstrapActions</code></li>'
-    '<li><code>elasticmapreduce:ListInstanceFleets</code></li>'
-    '<li><code>elasticmapreduce:DescribeCluster</code></li>'
-    '<li><code>elasticmapreduce:ListInstanceGroups</code></li></ul>'
-    'For information about the cluster'
-    ' steps, see <code>list-steps</code>.</p>')
+    'Provides  cluster-level details including status, hardware '
+    'and software configuration, VPC settings, bootstrap '
+    'actions, instance groups and so on. '
+    'Permissions needed for describe-cluster include '
+    'elasticmapreduce:ListBootstrapActions, '
+    'elasticmapreduce:ListInstanceFleets, '
+    'elasticmapreduce:DescribeCluster, '
+    'and elasticmapreduce:ListInstanceGroups.')
 
 CLUSTER_NAME = (
     '<p>The name of the cluster. If not provided, the default is "Development Cluster".</p>')
@@ -417,7 +409,7 @@ KERBEROS_ATTRIBUTES = (
      ' with a KDC in a different realm. This is the cross-realm principal password,'
      ' which must be identical across realms.</li>'
      ' <li><code>ADDomainJoinUser</code> - Required when establishing trust with an Active Directory'
-     ' domain. This is the User logon name of an AD account with sufficient privileges to join resouces to the domain.</li>'
+     ' domain. This is the User logon name of an AD account with sufficient privileges to join resources to the domain.</li>'
      ' <li><code>ADDomainJoinPassword</code> - The AD password for <code>ADDomainJoinUser</code>.</li>')
 
 # end create-cluster options help descriptions
@@ -508,3 +500,9 @@ AUTO_TERMINATION_POLICY = (
     'The configuration specifies the termination idle timeout'
     'threshold for an cluster.</p> '
 )
+
+EXECUTION_ROLE_ARN = (
+    '<p>You must grant the execution role the permissions needed '
+    'to access the same IAM resources that the step can access. '
+    'The execution role can be a cross-account IAM Role.</p> '
+)
